#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#-------------------------------------------------------------------------------
# This file is part of Mentat system (https://mentat.cesnet.cz/).
#
# Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
# Use of this source is governed by the MIT license, see LICENSE file.
#-------------------------------------------------------------------------------


"""
Description
-----------

This pluggable module provides default home page.


Provided endpoints
------------------

``/``
    Page providing home page.

    * *Authentication:* no authentication
    * *Methods:* ``GET``
"""


__author__ = "Jan Mach <jan.mach@cesnet.cz>"
__credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea.kropacova@cesnet.cz>"


#
# Flask related modules.
#
from flask_babel import lazy_gettext

#
# Custom modules.
#
from vial.app import VialBlueprint
from vial.view import SimpleView
from vial.view.mixin import HTMLMixin


BLUEPRINT_NAME = 'home'
"""Name of the blueprint as module global constant."""


class IndexView(HTMLMixin, SimpleView):
    """
    View presenting home page.
    """
    methods = ['GET']

    @classmethod
    def get_view_name(cls):
        """*Implementation* of :py:func:`vial.view.BaseView.get_view_name`."""
        return 'index'

    @classmethod
    def get_view_icon(cls):
        """*Implementation* of :py:func:`vial.view.BaseView.get_view_icon`."""
        return 'module-home'

    @classmethod
    def get_view_title(cls, **kwargs):
        """*Implementation* of :py:func:`vial.view.BaseView.get_view_title`."""
        return lazy_gettext('Welcome to Mentat!')

    @classmethod
    def get_menu_title(cls, **kwargs):
        """*Implementation* of :py:func:`vial.view.BaseView.get_menu_title`."""
        return lazy_gettext('Home')


#-------------------------------------------------------------------------------


class HomeBlueprint(VialBlueprint):
    """
    Pluggable module - home page (*home*).
    """

    @classmethod
    def get_module_title(cls):
        """*Implementation* of :py:func:`vial.app.VialBlueprint.get_module_title`."""
        return lazy_gettext('Home page pluggable module')


#-------------------------------------------------------------------------------


def get_blueprint():
    """
    Mandatory interface and factory function. This function must return a valid
    instance of :py:class:`vial.app.VialBlueprint` or :py:class:`flask.Blueprint`.
    """

    hbp = HomeBlueprint(
        BLUEPRINT_NAME,
        __name__,
        template_folder = 'templates'
    )

    hbp.register_view_class(IndexView, '/')

    return hbp
